kenji_player library

Classes

BarStyle
Caption
A representation of a single caption.
CenterPlayAndPauseWidgetStyle
ClosedCaption
Widget for displaying closed captions on top of a video.
ClosedCaptionFile
A structured representation of a parsed closed caption file.
DurationRange
Describes a discrete segment of time within a video using a start and end Duration.
KenjiPlayer
KenjiPlayerAd
KenjiPlayerController
KenjiPlayerState
KenjiPlayerStyle
KenjiPlayerSubtitle
LockStyle
PositionedOptions
ProgressBarStyle
SubRipCaptionFile
Represents a ClosedCaptionFile, parsed from the SubRip file format. See: https://en.wikipedia.org/wiki/SubRip
SubtitleData
SubtitleStyle
VideoAudioTrack
Represents an audio track in a video with its metadata.
VideoErrorState
VideoPlayer
Widget that displays the video controlled by controller.
VideoPlayerController
Controls a platform video player, and provides updates when the state is changing.
VideoPlayerOptions
VideoPlayerOptions can be optionally used to set additional player settings
VideoPlayerValue
The duration, current position, buffering state, error state and settings of a VideoPlayerController.
VideoPlayerWebOptions
VideoPlayerWebOptions can be optionally used to set additional web settings
VideoPlayerWebOptionsControls
VideoPlayerWebOptions can be used to set how control options are displayed
VideoProgressColors
Used to configure the VideoProgressIndicator widget's colors for how it describes the video's status.
VideoProgressIndicator
Displays the play/buffering status of the video controlled by controller.
VideoScrubber
A scrubber to control VideoPlayerControllers
VideoSource
WebVTTCaptionFile
Represents a ClosedCaptionFile, parsed from the WebVTT file format. See: https://en.wikipedia.org/wiki/WebVTT

Enums

DataSourceType
The way in which the video was originally loaded.
SubtitleIntializeType
SubtitleType
VideoFormat
The file format of the given video.
VideoViewType
The type of video view to be used.