LockStyle class

Constructors

LockStyle({BarStyle? bar, Widget? lock, Widget? locked, Color? backgroundColor, double paddingBeetwen = 12})
It is the style that will have all the icons and elements of the progress bar

Properties

backgroundColor Color
It is the background color that the gradient and the PreviewFrame will have
final
bar BarStyle
DEFAULT:
final
hashCode int
The hash code for this object.
no setterinherited
lock Widget
It is the icon that appears when you want to enter full screen.
final
locked Widget
It is the icon that appears when you want to exit the full screen.
final
paddingBeetwen double
It is the padding that will have the icons and the progressBar
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited